Domino
======


Introduction
------------

Domino intends to provide default configuration, frequently used modules, and functions for kick-off Drupal project development.


Requirements
------------

* [Admin Toolbar](https://www.drupal.org/project/admin_toolbar)
* [Configuration Split](https://www.drupal.org/project/config_split)
* [Features](https://www.drupal.org/project/features)
* [Module Filter](https://www.drupal.org/project/module_filter)
* [Permissions filtered by modules](https://www.drupal.org/project/pfm)
* [SMTP Authentication Support](https://www.drupal.org/project/smtp)


Recommended modules
-------------------

* [Mail Login](https://www.drupal.org/project/mail_login)
* [Override Node Options](https://www.drupal.org/project/override_node_options)
* [Twig Field Value](https://www.drupal.org/project/twig_field_value)
* [Twig Tweak](https://www.drupal.org/project/twig_tweak)


Installation
------------

* Install as you would normally install a contributed Drupal module. See: [drupal.org/node/895232](https://www.drupal.org/node/895232) for further information.


Configuration
-------------

The module has no menu or modifiable settings. There is no configuration.


Module features
---------------

* Automatic installing and enabling frequently used modules (when intalled via Composer)
* Default configuration for:
    * User roles
    * Site and Admin UI themes
    * Block layout
    * Configuration split
* Handling test users for development environments

### Automatic installing and enabling modules

Domino module includes dependencies on several frequently used modules which will be automatically installed (if Domino was installed via Composer) and enabled when Domino enabled.

List of non Core dependencies:

*  Admin Toolbar Extra Tools
*  Admin Toolbar
*  Configuration Split
*  Config Filter
*  Features
*  Features UI
*  Module Filter
*  Permissions filtered by modules
*  SMTP Authentication Support

### Default configuration

#### User roles

Domino module includes two preconfigured user roles: Developer and Manager.

#### Site and Admin UI themes

Domino module set Seven as Admin UI theme and Stark as Site theme.

#### Block layout

Domino module includes block layout for Seven theme.

#### Configuration split

Domino module includes configuration for 3 configuration splits:

* Development
* Staging
* Production

For start using splits:

1. In your configuration directory create splits root directory and 3 child directories, for example:

    ~~~
    config
    --split
    ----dev
    ----prod
    ----stage
    --sync
    ~~~

2. Set path to directories on split configuration page or in `settings*.php` file (recommended):

    ~~~
    $config['config_split.config_split.development']['status'] = TRUE;
    $config['config_split.config_split.staging']['status'] = TRUE;
    $config['config_split.config_split.production']['status'] = TRUE;
    ~~~

### Handling test users

Domino module can handle creating and enabling/disabling test users for different environments.

Domino will try to create and enable test user for every defined role (except Anonymous) on clearing cache if all these conditions will be passed:

* `application_mode` setting is not `production`. `production` is a default value.
* `test_users_password` setting is not empty. By default it is empty.

If user already exist it will be just enabled, password won't be changed.

If user included in exception list (`prod_users`) and `test_users_password` setting is not empty, this user's password will be updated to value of `test_users_password`.

Settings can be set in `settings*.php` file:

~~~
$config['domino_core.settings']['application_mode'] = 'development';
$config['domino_core.settings']['test_users_password'] = 'PASSWORD';
// Alternatively value can be obtained from environment variable.
// if (!empty($_ENV['TEST_USERS_PASSWORD'])) {
//   $config['domino_core.settings']['test_users_password'] = $_ENV['TEST_USERS_PASSWORD'];
// }
~~~

Value of `test_users_password` setting will be used as a password for all test users.

Test user username pattern is: `ROLE.test`. It is possible to use an alias for `ROLE`, it can be configured in `settings*.php` file:

~~~
$config['domino_core.settings']['test_users_map'] = [
  'administrator' => 'admin',
];
~~~

Note: `test_users_map` accepts arrays of user role machine name name and needed alias.

It is possible to define a list of users which shouldn't be disabled on production via setting `prod_users`:

~~~
$config['domino_core.settings']['prod_users'] = [
  'manager.test',
];
~~~

Note: `prod_users` accepts usernames.

On production environment Domino will disable all test users on any page load if any of conditions above won't pass.
If user included in exception list and `prod_users_password` setting is not empty, this user won't be disabled but it's password will be updated to value of `prod_users_password`.




